@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-__version__ = '1.0.6'
+__version__ = '1.1.0'
 
 
 import os
@@ -25,13 +25,6 @@ from logging import getLogger
 
 log = getLogger('butterfly')
 
-application = tornado.web.Application(
-    debug=tornado.options.options.debug,
-    cookie_secret=tornado.options.options.secret,
-    static_path=os.path.join(os.path.dirname(__file__), "static"),
-    template_path=os.path.join(os.path.dirname(__file__), "templates")
-)
-
 
 class url(object):
     def __init__(self, url):
@@ -50,5 +43,19 @@ class Route(tornado.web.RequestHandler):
     def log(self):
         return log
 
+if hasattr(tornado.options.options, 'debug'):
+    opts = dict(
+        debug=tornado.options.options.debug,
+        cookie_secret=tornado.options.options.secret)
+else:
+    opts = {}
+
+
+application = tornado.web.Application(
+    static_path=os.path.join(os.path.dirname(__file__), "static"),
+    template_path=os.path.join(os.path.dirname(__file__), "templates"),
+    **opts
+)
+
 
 import butterfly.routes
